Welcome to `Évariste`'s documentation!
======================================

TODO

.. note::

  Évariste is under active development. This is only a draft.

Download and install
--------------------

See the `main project page <http://git.framasoft.org/spalax/evariste>`_ for
instructions.

Usage
-----

Here are the command line options for `evariste`.

.. argparse::
    :module: evariste.main.options
    :func: commandline_parser
    :prog: evariste

Indices and tables
------------------

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
